<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en">
<context>
    <name>DotPlotDialog</name>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="17"/>
        <source>Dotplot</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="30"/>
        <source>Dotplot parameters</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="52"/>
        <source>Custom algorithm</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="99"/>
        <source>X axis sequence</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="112"/>
        <source>Minimum repeat length</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="119"/>
        <source>Y axis sequence</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="126"/>
        <source>Repeats  identity</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="151"/>
        <source>bp</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="179"/>
        <source>Heuristic based selection of repeat length so the number of repeats in the sequence will not exceed 1000</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="182"/>
        <source>1k</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="207"/>
        <source>%</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="229"/>
        <source>Resets repeats identity to 100%</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="232"/>
        <source>100</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="287"/>
        <source>Search inverted repeats</source>
        <translation>Search for inverted repeats</translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="294"/>
        <source>Search direct repeats</source>
        <translation>Search for direct repeats</translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="333"/>
        <location filename="../src/ui/DotPlotDialog.ui" line="340"/>
        <source>default</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="365"/>
        <source>Click to load a sequence from the file system. The sequence will be added to the combo boxes when it is loaded to the project</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="368"/>
        <source>Load Sequence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="393"/>
        <source>OK</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotDialog.ui" line="403"/>
        <source>Cancel</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>DotPlotFilesDialog</name>
    <message>
        <location filename="../src/ui/DotPlotFilesDialog.ui" line="48"/>
        <location filename="../src/ui/DotPlotFilesDialog.ui" line="142"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotFilesDialog.ui" line="23"/>
        <source>Build dotplot from sequences</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotFilesDialog.ui" line="38"/>
        <source>File with first sequence</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotFilesDialog.ui" line="55"/>
        <location filename="../src/ui/DotPlotFilesDialog.ui" line="149"/>
        <source>Join all sequences found in the file</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotFilesDialog.ui" line="75"/>
        <location filename="../src/ui/DotPlotFilesDialog.ui" line="169"/>
        <source>Gap size:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotFilesDialog.ui" line="108"/>
        <source>Compare sequence against itself</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotFilesDialog.ui" line="128"/>
        <source>File with second sequence</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotFilesDialog.ui" line="219"/>
        <source>Next</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/DotPlotFilesDialog.ui" line="229"/>
        <source>Cancel</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::DotPlotDialog</name>
    <message>
        <location filename="../src/DotPlotDialog.cpp" line="63"/>
        <source>Auto</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotDialog.cpp" line="64"/>
        <source>Suffix index</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotDialog.cpp" line="65"/>
        <source>Diagonals</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotDialog.cpp" line="274"/>
        <source>Open file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::DotPlotDialogs</name>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="142"/>
        <source>Task is already running</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="142"/>
        <source>Build or Load DotPlot task is already running</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="148"/>
        <source>Save dot-plot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="148"/>
        <source>Save dot-plot data before closing?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="154"/>
        <source>File opening error</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="154"/>
        <source>Error opening file %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="160"/>
        <source>Error</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="160"/>
        <source>Error opening files</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="166"/>
        <source>Sequences are different</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="166"/>
        <source>Current and loading sequences are different. Continue loading dot-plot anyway?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="172"/>
        <source>Wrong dot-plot file format, loading aborted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="178"/>
        <source>Both sequence alphabets must be 4-symbols DNA alphabets</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="184"/>
        <source>Too many results. Try to increase minimum repeat length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="172"/>
        <source>Wrong format</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="178"/>
        <source>Wrong alphabet types</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotClasses.cpp" line="184"/>
        <source>Too many results</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::DotPlotFilesDialog</name>
    <message>
        <location filename="../src/DotPlotFilesDialog.cpp" line="71"/>
        <source>Open first file</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilesDialog.cpp" line="88"/>
        <source>Open second file</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilesDialog.cpp" line="113"/>
        <source>Select files</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotFilesDialog.cpp" line="113"/>
        <source>Select files first to build dotplot</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::DotPlotLoadDocumentsTask</name>
    <message>
        <location filename="../src/DotPlotTasks.cpp" line="229"/>
        <source>DotPlot loading</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotTasks.cpp" line="274"/>
        <source>Detecting format error for file %1</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::DotPlotPlugin</name>
    <message>
        <location filename="../src/DotPlotPlugin.cpp" line="57"/>
        <source>Dotplot</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotPlugin.cpp" line="57"/>
        <source>Build dotplot for sequences</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::DotPlotSplitter</name>
    <message>
        <location filename="../src/DotPlotSplitter.cpp" line="52"/>
        <source>Multiple view synchronization lock</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotSplitter.cpp" line="53"/>
        <source>Keep aspect ratio</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotSplitter.cpp" line="54"/>
        <source>Zoom in (&lt;b&gt; + &lt;/b&gt;)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotSplitter.cpp" line="55"/>
        <source>Zoom out (&lt;b&gt; - &lt;/b&gt;)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotSplitter.cpp" line="56"/>
        <source>Reset zooming (&lt;b&gt;0&lt;/b&gt;)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotSplitter.cpp" line="57"/>
        <source>Select tool (&lt;b&gt;S&lt;/b&gt;)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotSplitter.cpp" line="58"/>
        <source>Hand tool (&lt;b&gt;H&lt;/b&gt;)</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::DotPlotViewAction</name>
    <message>
        <location filename="../src/DotPlotPlugin.h" line="79"/>
        <source>Show dot plot</source>
        <translation>Show dotplot</translation>
    </message>
</context>
<context>
    <name>U2::DotPlotViewContext</name>
    <message>
        <location filename="../src/DotPlotPlugin.cpp" line="79"/>
        <location filename="../src/DotPlotPlugin.cpp" line="205"/>
        <source>Build dotplot...</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::DotPlotWidget</name>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="109"/>
        <source>Parameters</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="112"/>
        <source>Save as image</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="115"/>
        <source>Save</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="118"/>
        <source>Load</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="121"/>
        <source>Remove</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="183"/>
        <source>Save/Load</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="916"/>
        <source> (min length %1, identity %2%)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="182"/>
        <source>Dotplot</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="441"/>
        <source>Save Dotplot</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="441"/>
        <location filename="../src/DotPlotWidget.cpp" line="487"/>
        <source>Dotplot files (*.dpt)</source>
        <translation></translation>
    </message>
    <message>
        <source>DotPlot Files (*.dpt)</source>
        <translation type="obsolete">Dotplot files (*.dpt)</translation>
    </message>
    <message>
        <location filename="../src/DotPlotWidget.cpp" line="487"/>
        <source>Load Dotplot</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::LoadDotPlotTask</name>
    <message>
        <location filename="../src/DotPlotTasks.cpp" line="62"/>
        <source>Wrong dotplot format</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/DotPlotTasks.h" line="64"/>
        <source>DotPlot loading</source>
        <translation>Dotplot loading</translation>
    </message>
</context>
<context>
    <name>U2::SaveDotPlotTask</name>
    <message>
        <location filename="../src/DotPlotTasks.h" line="40"/>
        <source>DotPlot saving</source>
        <translation>Dotplot saving</translation>
    </message>
</context>
</TS>
